@@ -1,8 +1,11 @@
-{-# LANGUAGE OverloadedStrings, ViewPatterns #-}
+{-# LANGUAGE ViewPatterns #-}
 -- TODO : learn how to use Functional Morphology instead
 -- |Simple default rules for English morphology
 module NLP.Minimorph.English where
 
+-- Only needed for older GHC, but let's avoid CPP for this instance.
+import Data.Monoid ((<>))
+
 import           Data.Char (isSpace, isUpper, toLower)
 import           Data.Text (Text)
 import qualified Data.Text as T
@@ -100,14 +103,16 @@ defaultNounPlural x
     | hasSibilantSuffix x   = sibilant_o
     | hasCoSuffix x         = sibilant_o
     | hasCySuffix x         = y_final
-    | "f"  `T.isSuffixOf` x = f_final
+    | "ff" `T.isSuffixOf` x = ff_final  -- quite often not the case
+    | "f" `T.isSuffixOf` x  = f_final   -- but this one as well, so both needed
     | otherwise             = plain
   where
     plain      = x            <> "s"
     sibilant_o = x            <> "es"
     y_final    = T.init x     <> "ies"
     f_final    = T.init x     <> "ves"
-    thesis     = tDropEnd 2 x <> "es"
+    ff_final   = T.dropEnd 2 x <> "ves"
+    thesis     = T.dropEnd 2 x <> "es"
 
 -- | Heuristics for 3rd person singular and past participle
 --   for an unknown regular verb. Doubling of final consonants
@@ -242,12 +247,12 @@ hasVowel_U_Prefix t =
 
 -- | Last two letters are a consonant and \'y\'.
 hasCySuffix :: Text -> Bool
-hasCySuffix (T.unpack . tTakeEnd 2 -> [x, 'y']) = isConsonant x
+hasCySuffix (T.unpack . T.takeEnd 2 -> [x, 'y']) = isConsonant x
 hasCySuffix _ = False
 
 -- | Last two letters are a consonant and \'o\'.
 hasCoSuffix :: Text -> Bool
-hasCoSuffix (T.unpack . tTakeEnd 2 -> [x, 'o']) = isConsonant x
+hasCoSuffix (T.unpack . T.takeEnd 2 -> [x, 'o']) = isConsonant x
 hasCoSuffix _ = False
 
 -- | Is a vowel.
