@@ -1,21 +1,14 @@
-{-# LANGUAGE OverloadedStrings #-}
 -- | Text utility functions.
 module NLP.Minimorph.Util
- ( tTakeEnd, tDropEnd, (<>), (<+>), tshow )
+ ( (<+>), tshow )
  where
 
+-- Only needed for older GHC, but let's avoid CPP for this instance.
 import Data.Monoid ((<>))
-import Data.Text (Text)
+
+import           Data.Text (Text)
 import qualified Data.Text as T
 
--- | @tTakeEnd n t@ returns the last @n@ letters of @t@.
-tTakeEnd :: Int -> Text -> Text
-tTakeEnd n t = T.drop (T.length t - n) t
-
--- | @tDropEnd n t@ drops the last @n@ letters of @t@.
-tDropEnd :: Int -> Text -> Text
-tDropEnd n x = T.take (T.length x - n) x
-
 infixr 6 <+>  -- matches Monoid.<>
 -- | Separated by space unless one of them is empty (in which case just
 --   the non-empty one).
